const LDAP_INJECTION_PATTERNS = [
  /\(\|\|.*?\)/, // Operador lógico OR en LDAP
  /\(\&\&.*?\)/, // Operador lógico AND en LDAP
  /\b(&(.*?=.*?))\b/i, // Consulta AND en LDAP
  /\b(\|(.*?=.*?))\b/i, // Consulta OR en LDAP
  /\*\)/, // Paréntesis de cierre después de un asterisco
  /\(.*?=.*?\)/i, // Paréntesis que contienen un signo igual
  /\(\d+\)/, // Dígitos dentro de paréntesis
  /\(\*\)/, // Asterisco dentro de paréntesis
  /\bobjectClass\b/i, // Atributo común de LDAP
  /ldap:\/\/|ldaps:\/\//i, // URLs de LDAP
  /\badmin\b/i, // Usuario común de LDAP
  /\bOU=/i, // Unidad Organizativa (Organizational Unit)
  /\bCN=/i, // Nombre Común (Common Name)
  /\bDC=/i, // Componente de Dominio (Domain Component)
  /\bUID=/i, // ID de Usuario (User ID)
  /\buserPassword\b/i, // Atributo de contraseña de usuario
  /\bpass\b/i, // Atributo de contraseña
  /\w+\s*=\s*['"][^'"]*['"]/, // Atributo=valor entre comillas
  /\/\/\//, // Múltiples barras diagonales
  /(?:\b\w+\b\()|(?:\)\b\w+\b)/i, // Patrones similares a funciones
];

/**
 * Detects if there is a potential LDAP injection in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential LDAP injection is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a series of regular expressions to look for common LDAP injection patterns in the input string.
 * Patterns include logical operators, common LDAP attributes, and special characters used in LDAP queries.
 *
 * @example
 * ```typescript
 * const input = "(uid=admin)(&)";
 * const isLDAPInjection = detectLDAPInjection(input);
 * console.log(isLDAPInjection); // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export function detectLDAPInjection(input: string): boolean {
  return LDAP_INJECTION_PATTERNS.some((pattern) => pattern.test(input));
}
